@@ -1,29 +1,23 @@
 ##
 ## Equal Risk Contribution Portfolio
 ##
-PERC <- function (Sigma, par = NULL, percentage = TRUE, ...){
+PERC <- function (Sigma, par = NULL, percentage = TRUE, optctrl = ctrl(), ...){
   if(!isSymmetric(Sigma)){
     stop("Matrix provided for Sigma is not symmetric.\n")
   }
   N <- ncol(Sigma)
+  mrc <- rep(1/N, N)
   if(is.null(par)){
-    par <- rep(1/N, N)
+    par <- mrc
   } else {
     if(length(par) != N){
       stop("Length of 'par' not comformable with dimension of 'Sigma'.\n")
     }
   }
   call <- match.call()
-  ## objective
-  f <- function(x, Sigma){
-    pr <- sqrt(t(x) %*% Sigma %*% x)
-    mrc <- c(x * Sigma %*% x) / pr
-    val <- sd(mrc)
-    return(val)
-  }
-  opt <- nlminb(start = par, objective = f, Sigma = Sigma,
-                lower = 0, upper = 1, ...)
-  w <- opt$par
+  ## calling rp() from cccp
+  opt <- rp(x0 = par, P = Sigma, mrc = mrc, optctrl = optctrl)
+  w <- drop(getx(opt))
   w <- w / sum(w)
   if(percentage) w <- w * 100
   if(is.null(dimnames(Sigma))){
@@ -31,7 +25,6 @@ PERC <- function (Sigma, par = NULL, percentage = TRUE, ...){
     } else {
       names(w) <- colnames(Sigma)
     }
-  obj <- new("PortSol", weights = w, opt = opt,
-             type = "Equal Risk Contribution", call = call)
-  return(obj)
+  new("PortSol", weights = w, opt = list(opt),
+      type = "Equal Risk Contribution", call = call)
 }
